#
# spec file for package perl-Lingua-EN-Inflect
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Lingua-EN-Inflect
Version:        1.905
Release:        1.17
%define cpan_name Lingua-EN-Inflect
Summary:        Convert singular to plural. Select "a" or "an"
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DC/DCONWAY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
*[_Note:_ This module is strictly in maintenance mode now. Take a look at
the newer Lingua::EN::Inflexion module, which offers a cleaner and more
convenient interface, has many more features (including plural->singular
inflexions), and is also much better tested. If you have existing code that
relies on Lingua::EN::Inflect, see the section of the documentation
entitled "CONVERTING FROM LINGUA::EN::INFLECT". ]*

The exportable subroutines of Lingua::EN::Inflect provide plural
inflections, "a"/"an" selection for English words, and manipulation of
numbers as words

Plural forms of all nouns, most verbs, and some adjectives are provided.
Where appropriate, "classical" variants (for example: "brother" ->
"brethren", "dogma" -> "dogmata", etc.) are also provided.

Pronunciation-based "a"/"an" selection is provided for all English words,
and most initialisms.

It is also possible to inflect numerals (1,2,3) to ordinals (1st, 2nd, 3rd)
and to English words ("one", "two", "three).

In generating these inflections, Lingua::EN::Inflect follows the Oxford
English Dictionary and the guidelines in Fowler's Modern English Usage,
preferring the former where the two disagree.

The module is built around standard British spelling, but is designed to
cope with common American variants as well. Slang, jargon, and other
English dialects are _not_ explicitly catered for.

Where two or more inflected forms exist for a single word (typically a
"classical" form and a "modern" form), Lingua::EN::Inflect prefers the more
common form (typically the "modern" one), unless "classical" processing has
been specified (see "MODERN VS CLASSICAL INFLECTIONS").

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Wed Dec  9 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.905
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.905  Tue Dec  8 19:21:16 2020
  - Removed gratuitous use of Env.pm
    (Thanks, Bob)
* Sun Apr 28 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.904
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.904  Sat Apr 27 22:01:03 2019
  - Corrected 'cyclops', 'triceratops', etc.
    (Thanks, Lady Aleena)
* Wed Nov  8 2017 coolo@suse.com
- updated to 1.903
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.903  Mon Oct 30 11:44:44 2017
  - Various bugs in documentation code debugged
    (Thanks, Kornel!)
* Sun May 28 2017 coolo@suse.com
- updated to 1.902
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.902  Sat May 27 22:23:21 2017
  - Noted the new conversion documentation in Lingua::EN::Inflexion
    (thanks Lady Aleena)
* Sun Jan  1 2017 coolo@suse.com
- updated to 1.901
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.901  Sun Jan  1 06:16:25 2017
  - Removed Build.PL (thanks SKAJI)
* Thu Jul 28 2016 coolo@suse.com
- updated to 1.900
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
* Fri May  8 2015 coolo@suse.com
- updated to 1.899
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.899  Wed May  6 06:34:22 2015
  - Fixed bug in ORD() where huge integers (in strings) were
    downgraded to floating point before being (incorrectly) inflected
    (thanks Dmytro!)
* Tue May  5 2015 coolo@suse.com
- updated to 1.897
  see /usr/share/doc/packages/perl-Lingua-EN-Inflect/Changes
  1.896  Mon Feb  4 13:10:48 2013
  - Fixed another POD nit (thanks Matthew)
  - Removed second authorship attribution as requested.
  - Vastly improved NUMWORDS (thanks Matthew, and Lady Aleena)
  1.897  Tue May  5 16:10:54 2015
  - Noted "print NUMWORDS($num)" gotcha in documentation (thanks Lady Aleena)
  - Fixed undef var bug in t/no_commas.t
    (thanks Matthew!)
  - Fixed words-below tests on things that aren't really numbers
  - Removed unneeded dependency on version
  - Doc nit knitted (thank-you Lady Aleena)
  - Added a pointer to Lingua::EN::Inflexion
* Wed Jun  5 2013 coolo@suse.com
- updated to 1.895
  - Fixed several dozen obscure plurals (thanks Tom)
  - Greatly improved the list of prepositions (thanks Tom)
  - Several minor doc nits cleaned up
  - Fixed 'miniseries', 'tv series' etc (thanks Lady Aleena)
  - NON-BACKWARDS COMPATIBLE CHANGE:
    WORDLIST now always add spaces around its final conjunction.
    Please report any cases where this is an adverse change.
  - Fixed a POD nit (thanks Gregor)
  - Added 'words_below', 'comma', and 'comma_every' options to NO()
    (Thanks Lady Aleena).
* Mon Jan 17 2011 coolo@novell.com
- initial package 1.893
  * created by cpanspec 1.78.03
